<?php

define( 'THEME_NAME', 'Fapowy' );
define( 'THEME_VERSION', '1.0' );
define( 'THEME_URI', get_template_directory_uri() );
define( 'THEME_INC', TEMPLATEPATH . '/inc' );

// Theme options in the option array fapowy
$foption = get_option( 'fapowy' ); 

if ( is_admin() )
	include_once( THEME_INC . '/admin/admin.php' );

include_once( THEME_INC . '/metabox/slider.php' );
include_once( THEME_INC . '/theme/widgets.php' );

/**
 * Set the content width
 */
$content_width = 610;

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
 
add_action( 'after_setup_theme', 'fap_setup' );

function fap_setup() {

	global $foption;
	
	add_editor_style();

	add_custom_background();
	
	add_theme_support( 'automatic-feed-links' );
	
	register_nav_menu( 'primary', __( 'Primary Menu', 'fap' ) );
		
	/** 
	 * Post thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	
	// We want the thumbnails be the options page set sizes (default: 640 pixels wide by 260 pixels tall) (larger images will be auto-cropped to fit)
	set_post_thumbnail_size( $foption['thumbnail_width'], $foption['thumbnail_height'], true ); 
	
	add_image_size( 'slider-image', 600, 270, true );
	
	/**
	 * Custom header for logo upload
	 */
	add_custom_image_header( '', 'fap_admin_header_style' );
	
	define( 'HEADER_TEXTCOLOR', 'c02905' ); // #c02905 is the color from style.css
	
	register_default_headers( array(
		'logo' => array(
			'url' => '%s/images/logo.png',
			'thumbnail_url' => '%s/images/logo.png',
			'description' => 'Logo.png from images folder'
		)
	) );
	
	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 */
	load_theme_textdomain( 'fap', TEMPLATEPATH . '/languages' );

	$locale = get_locale();
	$locale_file = TEMPLATEPATH . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );
}

/**
 * - Register script files
 * - Load the shortcodes
 * - Register the slider post type
 */
function fap_init() {
	
	// Register jQuery and theme javascript files
	if ( !is_admin() ) {
		wp_deregister_script( 'jquery' ); 
		wp_register_script( 'jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.4/jquery.min.js', false, '1.4.4' ); 
		wp_register_script( 'roundabout', get_bloginfo('template_directory') . '/js/jquery.roundabout-1.1.min.js', array('jquery'), '1.1', true );
		wp_register_script( 'colorbox', get_bloginfo('template_directory') . '/js/jquery.colorbox.min.js', array('jquery'), '1.3.9', true );
		wp_register_script( 'fap-script', get_bloginfo('template_directory') . '/js/script.js', array('jquery', 'colorbox'), '1.0', true );
	}
	
	// Get the shortcodes
	include_once( THEME_INC . '/theme/shortcodes.php' );	

	// Slider post type
	register_post_type( 'slider',
		array(
			'labels' => array(
				'name' => __( 'Slider' ),
				'singular_name' => __( 'Slide' ),
				'add_new' => __( 'Add Slide' ),
				'add_new_item' => __( 'Add New Slide' ),
				'edit_item' => __( 'Edit Slide' ),
				'new_item' => __( 'New Slide' ),
				'view' => __( 'View Slide' ),
				'view_item' => __( 'View Slide' ),
				'search_items' => __( 'Search Slides' ),
				'not_found' => __( 'No slides found' ),
				'not_found_in_trash' => __( 'No slides found in Trash' ),
			),
			'public' => true,
			'query_var' => true,
			'exclude_from_search' => true, // Exclude from search
			'menu_icon' => THEME_URI . '/inc/admin/images/slider-post-type.png',
			'supports' => array( 'title', 'editor', 'thumbnail' )
		)
	);
	
	/* Custom columns */
	add_action( 'manage_posts_custom_column', 'fap_custom_slider_columns' );
	add_filter( 'manage_edit-slider_columns', 'fap_slider_columns' );
	
	function fap_slider_columns( $columns ) {
		$columns = array(
			'cb' => '<input type="checkbox" />',
			'image' => __( 'Image' ),
			'title' => __( 'Title' ),
			'url' => __( 'Links to', 'fap' )
		);
		
		return $columns;
	}
	
	function fap_custom_slider_columns( $column ) {
		global $post;
		
		$custom = get_post_custom( $post->ID );
		
		if ( 'url' == $column )
			echo ( $custom["meta_url"][0] || $custom['meta_fullimage'][0] ) ? ( $custom["meta_url"][0] ? $custom["meta_url"][0] : $custom['meta_fullimage'][0] ) : get_permalink();
		elseif ( 'image' == $column )
			the_post_thumbnail( array(1000, 150) );	
	}
}

add_action( 'init', 'fap_init' );

/**
 * Register widget areas - Sidebar, footer, single and 404-page
 */
function fap_widgets_init() {
	
	// Sidebar
	register_sidebar( array (
		'name' => 'Sidebar',
		'id' => 'sidebar-widgets',
		'description' => __( 'Widgets for the sidebar', 'fap' ),
		'before_widget' => '<div class="widget %2$s" id="%1$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	) );

	// Single post
	register_sidebar( array (
		'name' => __( 'Single Post', 'fap' ),
		'id' => 'single-widgets',
		'description' => __( 'These widgets will be displayed after the content on single posts.', 'fap' ),
		'before_widget' => '<div class="single-widget %2$s" id="%1$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
	) );
	
	// Footer
	register_sidebar( array (
		'name' => __( 'Footer Widgets', 'fap' ),
		'id' => 'footer-widgets',
		'description' => __( 'Widgets for the footer', 'fap' ),
		'before_widget' => '<div class="footer-col %2$s" id="%1$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	) );

	// 404 page
	register_sidebar( array (
		'name' => __( '404 Page', 'fap' ),
		'id' => 'error-page-widgets',
		'description' => __( 'Widgets for the 404 error page', 'fap' ),
		'before_widget' => '<div class="widget %2$s" id="%1$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	) );
}

add_action( 'widgets_init', 'fap_widgets_init' );

/**
 * Clean up wp_head
 */
remove_action( 'wp_head', 'rsd_link' ); // Remove Really simple discovery link
remove_action( 'wp_head', 'wlwmanifest_link' ); // Remove Windows Live Writer link
remove_action( 'wp_head', 'wp_generator' ); // Remove the version number

function my_deregister_styles() {
	wp_deregister_style( 'cleaner-gallery' );
}

add_action( 'wp_print_styles', 'my_deregister_styles', 100 );

/**
 * Template for comments and pingbacks.
 * Used as a callback by wp_list_comments() for displaying the comments.
 */
function fap_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
    
	switch ( $comment->comment_type ) :
		case '' :
	?>
    
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
    
		<div id="comment-<?php comment_ID(); ?>">
        
            <div class="comment-author vcard">
                <?php echo get_avatar( $comment, 32 ); ?>
                <?php printf( __( '%s <span class="says">says:</span>', 'fap' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
            </div><!-- .comment-author .vcard -->
            
            <?php if ( $comment->comment_approved == '0' ) : ?>
                <em><?php _e( 'Your comment is awaiting moderation.'); ?></em>
                <br />
            <?php endif; ?>
    
            <div class="comment-meta commentmetadata"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
                <?php
                    /* translators: 1: date, 2: time */
                    printf( __( '%1$s at %2$s', 'fap' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Edit)' ), ' ' );
                ?>
            </div><!-- .comment-meta .commentmetadata -->
    
            <div class="comment-body"><?php comment_text(); ?></div>
    
            <div class="reply">
                <?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
            </div><!-- .reply -->
            
		</div><!-- #comment-##  -->

		<?php
			break;
            case 'pingback'  :
            case 'trackback' :
        ?>
    
        <li class="pingback">
            <p><?php _e( 'Pingback:', 'fap' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __('(Edit)', 'fap' ), ' ' ); ?></p>
        
	<?php	break;
	endswitch;
}

/**
 * "Continue Reading" link for excerpts
 */
add_filter( 'excerpt_more', 'fap_auto_excerpt_more' );
add_filter( 'get_the_excerpt', 'fap_custom_excerpt_more' );

function fap_continue_reading_link() {
	return '<p><a href="'. get_permalink() . '" class="more-link">' . __( 'Continue reading &raquo;', 'fap' ) . '</a></p>';
}

function fap_auto_excerpt_more( $more ) {
	return fap_continue_reading_link();
}

function fap_custom_excerpt_more( $output ) {
	
	if ( has_excerpt() && ! is_attachment() )
		$output .= fap_continue_reading_link();

	return $output;
}

/**
 * Prints HTML with date information
 * Adds year if the post not is from the current year
 */
function fap_date() {
	
	$year = ( get_the_date('Y') != date('Y') ) ? '<small>' . get_the_date('Y') . '</small>' : '';

	echo '<span>' . get_the_date('d') . '</span>' . get_the_date('M') . $year;	
}

/**
 * Link post thumbnail to the post 
 */
function fap_post_thumbnail( $html, $post_id, $post_image_id ) {
	
	if ( get_post_type() != 'slider' ) // Don't apply the link to slider thumbnails
		$html = '<a href="' . get_permalink( $post_id ) . '" title="' . esc_attr( get_post_field( 'post_title', $post_id ) ) . '">' . $html . '</a>';

	return $html;
}

add_filter( 'post_thumbnail_html', 'fap_post_thumbnail', 10, 3 );

/**
 * This changes the feed links to the your alternate feed URL.
 * Credits to the Hybrid theme
 */
function fap_feed_link( $output, $feed ) {

	global $foption;

	$url = esc_url( $foption['alternative_rss'] );

	if ( $url ) {
		$outputarray = array( 'rss' => $url, 'rss2' => $url, 'atom' => $url, 'rdf' => $url, 'comments_rss2' => '' );
		$outputarray[$feed] = $url;
		$output = $outputarray[$feed];
	}

	return $output;
}

function fap_other_feed_link( $link ) {

	global $foption;
	
	if ( $foption['direct_feed'] && $url = $foption['alternative_rss'] )
		$link = esc_url( $url );

	return $link;
}

add_filter( 'feed_link', 'fap_feed_link', 1, 2 );
add_filter( 'category_feed_link', 'fap_other_feed_link' );
add_filter( 'author_feed_link', 'fap_other_feed_link' );
add_filter( 'tag_feed_link', 'fap_other_feed_link' );
add_filter( 'search_feed_link', 'fap_other_feed_link' );

/**
 * Remove inline styles printed when the gallery shortcode is used.
 * Galleries are styled in style.css
 */
function fap_remove_gallery_css( $css ) {
	return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
}

add_filter( 'gallery_style', 'fap_remove_gallery_css' );

/**
 * Browser body class
 */
function fap_browser_body_class( $classes ) {
	
	global $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;

	if ( $is_gecko ) $classes[] = 'firefox';
	elseif ( $is_safari ) $classes[] = 'safari';
	elseif ( $is_chrome ) $classes[] = 'chrome';
	elseif ( $is_IE ) $classes[] = 'ie';
	elseif ( $is_opera ) $classes[] = 'opera';
	elseif ( $is_iphone ) $classes[] = 'iphone';
	
	return $classes;
}

add_filter( 'body_class', 'fap_browser_body_class' );

/**
 * Styles the header image displayed on the Appearance > Header admin panel
 */
function fap_admin_header_style() {
	echo '
		<style type="text/css">
			#headimg { background-repeat: no-repeat; background-position: 10px 10px; }
			#headimg #name { font: 54px Arial, Helvetica, sans-serif; font-weight: bold; letter-spacing: -1px; text-decoration: none; padding-left: 10px; }
			#headimg #desc { display: none!important; }
		</style>
	';
}

/**
 * Adds header logo CSS to wp_head if needed 
 */
function fap_theme_header_style() {													// c02905 is the default color
	if ( !get_header_image() && get_header_textcolor() && get_header_textcolor() != 'c02905' ) 
		echo '<style type="text/css"> #site-title a { color: #' . get_header_textcolor() . '; } </style>';
}

add_action( 'wp_head', 'fap_theme_header_style' );

/**
 * Check for theme update
 * Displays a update notice if there's a new version of the theme
 */
function fap_update_notice() {
	
	if ( is_admin() && current_user_can( 'manage_options' ) ) :
		
		include_once( ABSPATH . WPINC . '/feed.php' );
		
		$rss = fetch_feed( 'http://wpthemes.jayj.dk/themerss/faprss.xml' ); // Get the feed to check is there's any updates
		
		if ( !is_wp_error( $rss ) ) :
			$maxitems = $rss->get_item_quantity(1);
			$rss_items = $rss->get_items();
		endif;
		
		if ( $maxitems != 0 ) :
			
			foreach ( $rss_items as $item ) {
				if ( version_compare( $item->get_title(), THEME_VERSION ) > 0 )
					echo '<div id="update-nag">Version ' . esc_html( $item->get_title() ) .' for the Fapowy theme is available! <a href="' . esc_url( $item->get_permalink() ) .'">Click here to download the update</a></div>';
			}
			
		endif;
		
	endif; // is_admin()
}

add_action( 'admin_notices', 'fap_update_notice', 10 );

?>