<?php

/**
 * Initializes all the theme settings page functions. This function is used to create the themes 
 * settings page
 */

add_action( 'init', 'fap_admin_init' );

function fap_admin_init() {
	
	add_action( 'admin_menu', 'fap_admin' );
	add_action( 'admin_init', 'fap_register_settings' );
	add_action( 'admin_print_scripts', 'fap_quicktags' );

	function fap_admin() {
	
		// Add the page
		$fapadmin = add_theme_page( 'Fapowy Options', 'Fapowy', 'edit_theme_options', 'fapowy', 'fapowy_theme' );
		
		// Include the options
		include_once( THEME_INC . '/admin/fap-options.php' );
		
		// Add style and javascript
		add_action( "admin_print_styles-$fapadmin", "fap_admin_enqueue_style" );
		add_action( "admin_print_scripts-$fapadmin", "fap_admin_enqueue_script" );	
	}
	
	function fap_register_settings() {
		register_setting( 'fap_options', 'fapowy', 'fap_options_validate' ); // Register the settings
	}
	
	function fap_admin_enqueue_style() {
		wp_enqueue_style( 'fapadmin', THEME_URI . '/inc/admin/fap.css', '', THEME_VERSION );
	}
	
	function fap_admin_enqueue_script() {
		wp_enqueue_script( 'jquery-ui-core' );
		wp_enqueue_script( 'jquery-ui-tabs' );
		wp_register_script( 'fap-script', THEME_URI . '/inc/admin/fap.js', array( 'jquery' ) );
		wp_enqueue_script( 'fap-script' );
	}
	
	// Add quicktags.js
	function fap_quicktags() {
		wp_enqueue_script( 'fap_quicktags', THEME_URI . '/inc/admin/quicktags.js', array( 'quicktags' ) );
	}
	
	// Contextual help menu 
	function fap_admin_help( $contextual_help, $screen_id, $screen ) {

		if ( $screen_id == 'toplevel_page_fapowy' ) {
			$contextual_help .= '<p>' . __( 'If you need any help with theme, please refer to the documentation included in the download.', 'fap' ) . '</p>';
			
			$contextual_help .= '<p>' . sprintf( __( 'If you have any questions that are beyond the scope of the documentation, feel free to email via my <a href="%s">user page contact form here</a>.', 'fap' ), 'http://themeforest.net/user/jayjdk') . '</p>';
			
			$contextual_help .= '<p>' . sprintf( __( 'If you change the thumbnail size, I recommend you to use the <a href="%s">Regenerate Thumbnails</a> plugin to regenerate your images with the right dimensions.', 'fap' ), 'http://wordpress.org/extend/plugins/regenerate-thumbnails/') . '</p>';
			 
			return $contextual_help;
		}

		return $contextual_help;
	}

	add_action( 'contextual_help', 'fap_admin_help', 10, 3 );

} // fap_admin_init()

?>