<?php

/**
 * Create a meta box for slider information when you create a new slide
 *
 * Credits: Spencer Finnell ( http://spencerfinnell.com/archive/wordpress-custom-write-panels )
 */

add_action( 'admin_menu', 'fap_create_meta_box' );

function fap_create_meta_box() {
	add_meta_box( 'fap-slider-meta-box', 'Slider', 'fap_display_meta_slider', 'slider', 'normal', 'low');
}

function fap_display_meta_slider() {
    global $meta;
	fap_post_meta( $post->ID );
?>

<div class="form-wrap">

    <div class="form-field">
        <label for="slider-image">Full size image</label>
        <input type="text" name="fap_meta[fullimage]" value="<?php echo $meta[ 'fullimage' ]; ?>" style="width:99%;" id="slider-image" />
        <p><?php _e( 'If you want this to link to the full size image, type the URL here', 'fap' ); ?></p>
    </div>
    
    <div class="form-field">
        <label for="slider-url">URL</label>
        <input type="text" name="fap_meta[url]" value="<?php echo $meta[ 'url' ]; ?>" style="width:99%;" id="slider-url" />
        <p><?php _e( 'If want it to link to a post, another site or something else than the fulls size image, type the URL here', 'fap' ); ?></p>
    </div>
    
</div>

<?php
}

/**
 * Verify and save meta. Don't save if there is no specific meta, it is a revision,
 * or the current user can't edit posts.
 */
function fap_save_meta_box( $post_id, $post )
{
	global $post, $type;

	$post = get_post( $post_id );

	if ( !isset( $_POST[ "fap_meta" ] ) )
		return;

	if ( $post->post_type == 'revision' )
		return;

	if ( !current_user_can( 'edit_post', $post_id ) )
		return; 

	do_action( 'fap_save_meta', $post, $_POST[ "fap_meta" ] );

	foreach( $_POST[ "fap_meta" ] as $key => $meta_box ) {
		$key = 'meta_' . $key;
		$curdata = $meta_box;
		$olddata = get_post_meta( $post_id, $key, true );

		if ( $olddata == "" && $curdata != "" )
			add_post_meta( $post_id, $key, $curdata );
		elseif ( $curdata != $olddata )
			update_post_meta( $post_id, $key, $curdata, $olddata );
		elseif ( $curdata == "" )
			delete_post_meta( $post_id, $key );
	}

	do_action( 'fap_saved_meta', $post, $_POST[ "fap_meta" ] );
}

add_action( 'save_post', 'fap_save_meta_box', 1, 2 );

/**
 * Gathers all meta objects attached to a certain posts.
 * Excludes WordPress internal meta and creates an array of data.
 */
function fap_post_meta( $post_id = '' ) {
	global $meta, $post, $wpdb;

	if ( empty( $post_id ) )
		$post_id = $post->ID;

	$meta = array();
	$custom_field_keys = get_post_custom_keys( $post_id );

	if ( $custom_field_keys ) {
		
		foreach( $custom_field_keys as $key => $value ) {
			$valuet = trim( $value );

			if ( '_' == $valuet{0} )
				continue;

			$value_short = str_replace( 'meta_', "", $valuet );

			$meta[ $value_short ] = get_post_meta( $post_id, $value, true );
		}
	}

	return $meta;
}

?>